@@ -1,8 +1,10 @@
 import logging
-from typing import List, Optional
+from typing import List, Optional, Union
 
 from loralogger.handlers import LogToESHandler
 from loralogger.instances import LoggerInstances
+from loralogger.loggers.logger import LoraLoggerClass
+
 
 # adapted from https://dock2learn.com/tech/create-a-reusable-logger-factory-for-python-projects/
 
@@ -17,7 +19,8 @@ class LoraLogger:
         log_to_es: bool = False,
         log_to_console: bool = False,
         log_to_syslog: bool = False,
-    ) -> logging.Logger:
+        skip_queue: bool = False,
+    ) -> LoraLoggerClass:
         logger_name: str = label or "loralogger"
 
         logger_format: str = format or "| %(levelname)-9s | %(asctime)s | %(message)s"
@@ -41,9 +44,7 @@ class LoraLogger:
         logger_handlers: List = []
 
         if log_to_es:
-            logger_instance = LoggerInstances.from_str(logger_name)
-
-            es_handlers = LogToESHandler(logger_instance)
+            es_handlers = LogToESHandler(logger_name, skip_queue)
             logger_handlers.append(es_handlers)
 
         if log_to_console:
@@ -54,8 +55,11 @@ class LoraLogger:
             syslog_handler = logging.handlers.SysLogHandler()  # type: ignore
             logger_handlers.append(syslog_handler)
 
+        # we register our logger class here, and add our custom record factory
+        logging.setLoggerClass(LoraLoggerClass)
+
         # We create our own Logger instance here, and set the default level.
-        logger: logging.Logger = logging.getLogger(logger_name)
+        logger = logging.getLogger(logger_name)
         logger.setLevel(logger_mapper[logger_level])
 
         # Add handlers for it, including the log format
@@ -65,44 +69,49 @@ class LoraLogger:
 
             logger.addHandler(handler)
 
-        return logger
+        return logger  # type: ignore
 
     @staticmethod
     def get_logger(
-        label: LoggerInstances,
+        label: Union[LoggerInstances, str],
         format: Optional[str] = None,
         date_format: Optional[str] = None,
         level: Optional[str] = None,
         log_to_es: bool = True,
         log_to_console: bool = False,
         log_to_syslog: bool = False,
-    ) -> logging.Logger:
+        skip_queue: bool = False,
+    ) -> LoraLoggerClass:
         """Static method to generate a logger with specific label and format.
 
         Args:
-            label (str): log label, will become the index in elasticsearch if log_to_es is True. Defaults to None.
+            label (LoggerInstances | str): log label, will become the index in elasticsearch if log_to_es is True. Defaults to None.
             format (str, optional): default log format. Defaults to None.
             date_format (str, optional): date format for the log. Defaults to None.
             level (str, optional): default logger level. Defaults to None.
             log_to_es (bool, optional): send the log to Elasticsearch. Defaults to False.
             log_to_console (bool, optional): also log to console. Defaults to False.
             log_to_syslog (bool, optional): also log to syslog. Defaults to False.
+            skip_queue (bool, optional): skip the logger from sending to RabbitMQ and send logs directly to ES instance
 
         Returns:
-            logging.Logger: custom logger instance
+            LoraLoggerClass: Lora's custom logger instance
         """
 
-        if not LoggerInstances.has_value(label):
-            raise TypeError("Not a valid LoggerInstance label")
+        if isinstance(label, LoggerInstances):
+            label_str = label.value
+        else:
+            label_str = label
 
         logger = LoraLogger.__create_logger(
-            label.value,
+            label_str,
             format,
             date_format,
             level,
             log_to_es,
             log_to_console,
             log_to_syslog,
+            skip_queue,
         )
 
         return logger
