@@ -1,5 +1,14 @@
 import traceback
 from typing import Tuple
+from requests.adapters import HTTPAdapter, Retry
+
+RETRY_HTTP_ADAPTER = HTTPAdapter(
+    max_retries=Retry(
+        total=5,
+        backoff_factor=1,
+        status_forcelist=[502, 503, 504],
+    )
+)
 
 LOGRECORD_KEYS = [
     "name",
